# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service


class RdsPostgreSQL(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(RdsPostgreSQL, "_instance"):
            with RdsPostgreSQL._instance_lock:
                if not hasattr(RdsPostgreSQL, "_instance"):
                    RdsPostgreSQL._instance = object.__new__(cls)
        return RdsPostgreSQL._instance

    def __init__(self, region='cn-north-1'):
        self.service_info = RdsPostgreSQL.get_service_info(region)
        self.api_info = RdsPostgreSQL.get_api_info()
        self.domain_cache = {}
        self.fallback_domain_weights = {}
        self.update_interval = 10
        self.lock = threading.Lock()
        super(RdsPostgreSQL, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info_map = {
            'cn-north-1': ServiceInfo("xxx.xxx.xxx",
                                      {'Accept': 'application/json'},
                                      Credentials('', '', 'rds_postgresql', 'cn-north-1'), 10, 10),
        }
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('Cant find the region, please check it carefully')

        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "CreateDBInstance": ApiInfo("POST", "/", {"Action": "CreateDBInstance", "Version": "2018-01-01"}, {}, {}),
            "CreateDBInstanceIPList": ApiInfo("POST", "/", {"Action": "CreateDBInstanceIPList", "Version": "2018-01-01"}, {}, {}),
            "CreateAccount": ApiInfo("POST", "/", {"Action": "CreateAccount", "Version": "2018-01-01"}, {}, {}),
            "ModifyDatabaseOwner": ApiInfo("POST", "/", {"Action": "ModifyDatabaseOwner", "Version": "2018-01-01"}, {}, {}),
            "CreateDatabase": ApiInfo("POST", "/", {"Action": "CreateDatabase", "Version": "2018-01-01"}, {}, {}),
        }
        return api_info

    def common_handler(self, api, form):
        params = dict()
        try:
            res = self.post(api, params, form)
            res_json = json.loads(res)
            return res_json
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    def common_json_handler(self, api, body):
        params = dict()
        try:
            body = json.dumps(body)
            res = self.json(api, params, body)
            res_json = json.loads(res)
            return res_json
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    def create_instance(self, form):
        try:
            return self.common_json_handler("CreateDBInstance", form)
        except Exception as e:
            raise Exception(str(e))

    def create_instance_white_list(self, form):
        try:
            return self.common_json_handler("CreateDBInstanceIPList", form)
        except Exception as e:
            raise Exception(str(e))

    def create_account(self, form):
        try:
            return self.common_json_handler("CreateAccount", form)
        except Exception as e:
            raise Exception(str(e))

    def modify_database_owner(self, form):
        try:
            return self.common_json_handler("ModifyDatabaseOwner", form)
        except Exception as e:
            raise Exception(str(e))

    def create_database(self, form):
        try:
            return self.common_json_handler("CreateDatabase", form)
        except Exception as e:
            raise Exception(str(e))




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_callback.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvod/business/vod_callback.proto\x12\x1eVolcengine.Vod.Models.Business*V\n\x13VodCallbackAuthType\x12\x1f\n\x1bVodCallbackAuthTypeDisabled\x10\x00\x12\x1e\n\x1aVodCallbackAuthTypeEnabled\x10\x01\x42\xcf\x01\n)com.volcengine.service.vod.model.businessB\x0bVodCallbackP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_VODCALLBACKAUTHTYPE = DESCRIPTOR.enum_types_by_name['VodCallbackAuthType']
VodCallbackAuthType = enum_type_wrapper.EnumTypeWrapper(_VODCALLBACKAUTHTYPE)
VodCallbackAuthTypeDisabled = 0
VodCallbackAuthTypeEnabled = 1


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\013VodCallbackP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODCALLBACKAUTHTYPE._serialized_start=67
  _VODCALLBACKAUTHTYPE._serialized_end=153
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodListCdnPvDataRequest

if __name__ == '__main__':
    vod_service = VodService()
    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')
    try:
        req = VodListCdnPvDataRequest()
        req.Domains = 'your domian'
        req.StartTimestamp = 0
        req.EndTimestamp = 0
        resp = vod_service.list_cdn_pv_data(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code != '':
            print(resp.ResponseMetadata.Error)



# coding: utf-8


class ServiceInfo(object):
    def __init__(self, host, header, credentials, connection_timeout, socket_timeout, scheme='http'):
        self.host = host
        self.header = header
        self.credentials = credentials
        self.connection_timeout = connection_timeout
        self.socket_timeout = socket_timeout
        self.scheme = scheme



# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo


class NLPService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(NLPService, "_instance"):
            with NLPService._instance_lock:
                if not hasattr(NLPService, "_instance"):
                    NLPService._instance = object.__new__(cls)
        return NLPService._instance

    def __init__(self):
        self.service_info = NLPService.get_service_info()
        self.api_info = NLPService.get_api_info()
        super(NLPService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("open.volcengineapi.com", {},
                                   Credentials('', '', 'nlp_gateway', 'cn-north-1'), 10, 10)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "KeyphraseExtractionExtract": ApiInfo("POST", "/", {"Action": "KeyphraseExtractionExtract", "Version": "2020-09-01"}, {}, {}),
            "TextCorrectionZhCorrect": ApiInfo("POST", "/", {"Action": "TextCorrectionZhCorrect", "Version": "2020-09-01"}, {}, {}),
            "TextCorrectionEnCorrect": ApiInfo("POST", "/", {"Action": "TextCorrectionEnCorrect", "Version": "2020-09-01"}, {}, {}),
            "SentimentAnalysis": ApiInfo("POST", "/", {"Action": "SentimentAnalysis", "Version": "2020-12-01"}, {}, {}),
            "TextSummarization": ApiInfo("POST", "/", {"Action": "TextSummarization", "Version": "2020-12-01"}, {}, {}),
            "EssayAutoGrade": ApiInfo("POST", "/", {"Action": "EssayAutoGrade", "Version": "2021-05-20"}, {}, {}),
            "NovelCorrection": ApiInfo("POST", "/", {"Action": "NovelCorrection", "Version": "2021-07-22"}, {}, {}),
        }
        return api_info

    def common_json_handler(self, api, body):
        params = dict()
        try:
            body = json.dumps(body)
            res = self.json(api, params, body)
            res_json = json.loads(res)
            return res_json
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    def keyphrase_extraction_extract(self, body):
        try:
            res_json = self.common_json_handler("KeyphraseExtractionExtract", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def text_correction_zh_correct(self, body):
        try:
            res_json = self.common_json_handler("TextCorrectionZhCorrect", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def text_correction_en_correct(self, body):
        try:
            res_json = self.common_json_handler("TextCorrectionEnCorrect", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def sentiment_analysis(self, body):
        try:
            res_json = self.common_json_handler("SentimentAnalysis", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def text_summarization(self, body):
        try:
            res_json = self.common_json_handler("TextSummarization", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def essay_auto_grade(self, body):
        try:
            res_json = self.common_json_handler("EssayAutoGrade", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    def novel_correction(self, body):
        try:
            res_json = self.common_json_handler("NovelCorrection", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    body = {
       "FileName": "ecb1be9b71974916a529b936702783cb.mp3",
    }

    print(notify_service.commit_resource_upload(body))



from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("your ak")
    secretNumberService.set_sk("your sk")

    click2_call_lite_form = {
        "Caller": "137XXXX8257",
        "Callee": "158XXXX9130",
        "NumberPoolNo": "NPXXXXX810901043",
    }
    print(secretNumberService.click2_call_lite(click2_call_lite_form))


# coding : utf-8
from collections import OrderedDict

try:
    from urllib import urlencode
except:
    from urllib.parse import urlencode


class Request(object):
    def __init__(self):
        self.schema = ''
        self.method = ''
        self.host = ''
        self.path = ''
        self.headers = OrderedDict()
        self.query = OrderedDict()
        self.body = ''
        self.form = dict()
        self.connection_timeout = 0
        self.socket_timeout = 0

    def set_shema(self, schema):
        self.schema = schema

    def set_method(self, method):
        self.method = method

    def set_host(self, host):
        self.host = host

    def set_path(self, path):
        self.path = path

    def set_headers(self, headers):
        self.headers = headers

    def set_query(self, query):
        self.query = query

    def set_body(self, body):
        self.body = body

    def set_connection_timeout(self, connection_timeout):
        self.connection_timeout = connection_timeout

    def set_socket_timeout(self, socket_timeout):
        self.socket_timeout = socket_timeout

    def build(self, doseq=0):
        return self.schema + '://' + self.host + self.path + '?' + urlencode(self.query, doseq)



# coding:utf-8


class Credentials(object):
    def __init__(self, ak, sk, service, region):
        self.ak = ak
        self.sk = sk
        self.service = service
        self.region = region

    def set_ak(self, ak):
        self.ak = ak

    def set_sk(self, sk):
        self.sk = sk



# coding:utf-8
from __future__ import print_function

from volcengine.example.rtc.RtcService import RtcService

if __name__ == '__main__':
    # using your own AK and SK
    AK = 'Your_AK'
    SK = 'Your_SK'

    # Firstly , init an RTCService Class
    rtc_service = RtcService()

    # Then , Set your AK and SK
    rtc_service.set_ak(AK)
    rtc_service.set_sk(SK)

    # You can using this API now ! Here are some Examples
    params = dict()
    params['AppId'] = 'Your_AppId'
    params['StartTime'] = '2022-07-06T12:00:00+08:00'
    params['EndTime'] = '2022-07-06T14:00:00+08:00'
    # optional params
    # params['RoomId'] = 'Your_RoomId'
    # params['PageNum'] = 'PageNum'
    # params['PageSize'] = 'PageSize'

    resp = rtc_service.list_room_information(params)
    print(resp)



# coding:utf-8


class ApiInfo(object):
    def __init__(self, method, path, query, form, header):
        self.method = method
        self.path = path
        self.query = query
        self.form = form
        self.header = header

    def __str__(self):
        return 'method: ' + self.method + ', path: ' + self.path



# coding:utf-8

from __future__ import print_function

import threading
from zlib import crc32

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service


class VodServiceConfig(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(cls, "_instance"):
            with cls._instance_lock:
                if not hasattr(cls, "_instance"):
                    cls._instance = object.__new__(cls)
        return cls._instance

    def __init__(self, region='cn-north-1'):
        self.service_info = VodServiceConfig.get_service_info(region)
        self.api_info = VodServiceConfig.get_api_info()
        self.domain_cache = {}
        self.fallback_domain_weights = {}
        self.update_interval = 10
        self.lock = threading.Lock()
        super(VodServiceConfig, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info_map = {
            'cn-north-1': ServiceInfo("vod.volcengineapi.com", {'Accept': 'application/json'},
                                      Credentials('', '', 'vod', 'cn-north-1'), 60, 60),
        }
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('Cant find the region, please check it carefully')

        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            # 播放
            "GetPlayInfo": ApiInfo("GET", "/", {"Action": "GetPlayInfo", "Version": "2020-08-01"}, {}, {}),
            "GetAllPlayInfo": ApiInfo("GET", "/", {"Action": "GetAllPlayInfo", "Version": "2022-01-01"}, {}, {}),
            "GetPrivateDrmPlayAuth": ApiInfo("GET", "/", {"Action": "GetPrivateDrmPlayAuth", "Version": "2020-08-01"}, {}, {}),
            "GetHlsDecryptionKey": ApiInfo("GET", "/", {"Action": "GetHlsDecryptionKey", "Version": "2020-08-01"}, {}, {}),
            "GetPlayInfoWithLiveTimeShiftScene": ApiInfo("GET", "/", {"Action": "GetPlayInfoWithLiveTimeShiftScene", "Version": "2021-11-01"}, {}, {}),
            # 上传
            "UploadMediaByUrl": ApiInfo("GET", "/", {"Action": "UploadMediaByUrl", "Version": "2020-08-01"}, {}, {}),
            "QueryUploadTaskInfo": ApiInfo("GET", "/", {"Action": "QueryUploadTaskInfo", "Version": "2020-08-01"}, {}, {}),
            "ApplyUploadInfo": ApiInfo("GET", "/", {"Action": "ApplyUploadInfo", "Version": "2020-08-01"}, {}, {}),
            "CommitUploadInfo": ApiInfo("GET", "/", {"Action": "CommitUploadInfo", "Version": "2020-08-01"}, {}, {}),
            # 媒资
            "UpdateMediaInfo": ApiInfo("GET", "/", {"Action": "UpdateMediaInfo", "Version": "2020-08-01"}, {}, {}),
            "UpdateMediaPublishStatus": ApiInfo("GET", "/", {"Action": "UpdateMediaPublishStatus", "Version": "2020-08-01"}, {}, {}),
            "GetMediaInfos": ApiInfo("GET", "/", {"Action": "GetMediaInfos", "Version": "2020-08-01"}, {}, {}),
            "GetRecommendedPoster": ApiInfo("GET", "/", {"Action": "GetRecommendedPoster", "Version": "2020-08-01"}, {}, {}),
            "DeleteMedia": ApiInfo("GET", "/", {"Action": "DeleteMedia", "Version": "2020-08-01"}, {}, {}),
            "DeleteTranscodes": ApiInfo("GET", "/", {"Action": "DeleteTranscodes", "Version": "2020-08-01"}, {}, {}),
            "GetMediaList": ApiInfo("GET", "/", {"Action": "GetMediaList", "Version": "2020-08-01"}, {}, {}),
            "GetSubtitleInfoList": ApiInfo("GET", "/", {"Action": "GetSubtitleInfoList", "Version": "2020-08-01"}, {}, {}),
            "UpdateSubtitleStatus": ApiInfo("GET", "/", {"Action": "UpdateSubtitleStatus", "Version": "2020-08-01"}, {}, {}),
            "UpdateSubtitleInfo": ApiInfo("GET", "/", {"Action": "UpdateSubtitleInfo", "Version": "2020-08-01"}, {}, {}),
            "GetAuditFramesForAudit": ApiInfo("GET", "/", {"Action": "GetAuditFramesForAudit", "Version": "2021-11-01"}, {}, {}),
            "GetMLFramesForAudit": ApiInfo("GET", "/", {"Action": "GetMLFramesForAudit", "Version": "2021-11-01"}, {}, {}),
            "GetBetterFramesForAudit": ApiInfo("GET", "/", {"Action": "GetBetterFramesForAudit", "Version": "2021-11-01"}, {}, {}),
            "GetAudioInfoForAudit": ApiInfo("GET", "/", {"Action": "GetAudioInfoForAudit", "Version": "2021-11-01"}, {}, {}),
            "GetAutomaticSpeechRecognitionForAudit": ApiInfo("GET", "/", {"Action": "GetAutomaticSpeechRecognitionForAudit", "Version": "2021-11-01"}, {}, {}),
            "GetAudioEventDetectionForAudit": ApiInfo("GET", "/", {"Action": "GetAudioEventDetectionForAudit", "Version": "2021-11-01"}, {}, {}),
            "CreateVideoClassification": ApiInfo("GET", "/", {"Action": "CreateVideoClassification", "Version": "2021-01-01"}, {}, {}),
            "UpdateVideoClassification": ApiInfo("GET", "/", {"Action": "UpdateVideoClassification", "Version": "2021-01-01"}, {}, {}),
            "DeleteVideoClassification": ApiInfo("GET", "/", {"Action": "DeleteVideoClassification", "Version": "2021-01-01"}, {}, {}),
            "ListVideoClassifications": ApiInfo("GET", "/", {"Action": "ListVideoClassifications", "Version": "2021-01-01"}, {}, {}),
            "ListSnapshots": ApiInfo("GET", "/", {"Action": "ListSnapshots", "Version": "2021-01-01"}, {}, {}),
            # 转码
            "StartWorkflow": ApiInfo("GET", "/", {"Action": "StartWorkflow", "Version": "2020-08-01"}, {}, {}),
            "RetrieveTranscodeResult": ApiInfo("GET", "/", {"Action": "RetrieveTranscodeResult", "Version": "2020-08-01"}, {}, {}),
            # 空间管理
            "CreateSpace": ApiInfo("GET", "/", {"Action": "CreateSpace", "Version": "2021-01-01"}, {}, {}),
            "ListSpace": ApiInfo("GET", "/", {"Action": "ListSpace", "Version": "2021-01-01"}, {}, {}),
            "GetSpaceDetail": ApiInfo("GET", "/", {"Action": "GetSpaceDetail", "Version": "2022-01-01"}, {}, {}),
            "UpdateSpace": ApiInfo("GET", "/", {"Action": "UpdateSpace", "Version": "2021-01-01"}, {}, {}),
            "UpdateSpaceUploadConfig": ApiInfo("GET", "/", {"Action": "UpdateSpaceUploadConfig", "Version": "2022-01-01"}, {}, {}),
            # 分发加速
            "ListDomain": ApiInfo("GET", "/", {"Action": "ListDomain", "Version": "2021-01-01"}, {}, {}),
            "CreateCdnRefreshTask": ApiInfo("GET", "/", {"Action": "CreateCdnRefreshTask", "Version": "2021-01-01"}, {}, {}),
            "CreateCdnPreloadTask": ApiInfo("GET", "/", {"Action": "CreateCdnPreloadTask", "Version": "2021-01-01"}, {}, {}),
            "ListCdnTasks": ApiInfo("GET", "/", {"Action": "ListCdnTasks", "Version": "2022-01-01"}, {}, {}),
            "ListCdnAccessLog": ApiInfo("GET", "/", {"Action": "ListCdnAccessLog", "Version": "2022-01-01"}, {}, {}),
            "ListCdnTopAccessUrl": ApiInfo("GET", "/", {"Action": "ListCdnTopAccessUrl", "Version": "2022-01-01"}, {}, {}),
            "DescribeVodDomainBandwidthData": ApiInfo("GET", "/", {"Action": "DescribeVodDomainBandwidthData", "Version": "2020-08-01"}, {}, {}),
            "ListCdnUsageData": ApiInfo("GET", "/", {"Action": "ListCdnUsageData", "Version": "2022-01-01"}, {}, {}),
            "ListCdnStatusData": ApiInfo("GET", "/", {"Action": "ListCdnStatusData", "Version": "2022-01-01"}, {}, {}),
            "DescribeIpInfo": ApiInfo("GET", "/", {"Action": "DescribeIpInfo", "Version": "2022-01-01"}, {}, {}),
            "ListCdnPvData": ApiInfo("GET", "/", {"Action": "ListCdnPvData", "Version": "2022-01-01"}, {}, {}),
            # 回调管理
            "AddCallbackSubscription": ApiInfo("GET", "/", {"Action": "AddCallbackSubscription", "Version": "2021-12-01"}, {}, {}),
            "SetCallbackEvent": ApiInfo("GET", "/", {"Action": "SetCallbackEvent", "Version": "2022-01-01"}, {}, {}),

        }
        return api_info

    @staticmethod
    def crc32(file_path):
        prev = 0
        for eachLine in open(file_path, "rb"):
            prev = crc32(eachLine, prev)
        return prev & 0xFFFFFFFF



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_smart_strategy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%vod/business/vod_smart_strategy.proto\x12\x1eVolcengine.Vod.Models.Business\x1a\x1dvod/business/vod_common.proto\"\xbb\x02\n%VodGetSmartStrategyLitePlayInfoResult\x12V\n\nStreamType\x18\x01 \x01(\x0e\x32\x42.Volcengine.Vod.Models.Business.VodSmartStrategyResponseStreamType\x12X\n\x0f\x44\x61taStoreStatus\x18\x02 \x01(\x0e\x32?.Volcengine.Vod.Models.Business.VodSmartStrategyDataStoreStatus\x12G\n\rPlayInfoModel\x18\x03 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodPlayInfoModel\x12\x17\n\x0fOriginalPlayUrl\x18\x04 \x01(\t*\x83\x02\n\"VodSmartStrategyResponseStreamType\x12/\n+UndefinedVodSmartStrategyResponseStreamType\x10\x00\x12\x34\n0OriginalStreamVodSmartStrategyResponseStreamType\x10\x01\x12:\n6StrategyEncodeStreamVodSmartStrategyResponseStreamType\x10\x02\x12:\n6FallbackEncodeStreamVodSmartStrategyResponseStreamType\x10\x03*\xe6\x01\n\x1fVodSmartStrategyDataStoreStatus\x12,\n(UndefinedVodSmartStrategyDataStoreStatus\x10\x00\x12+\n\'NotExistVodSmartStrategyDataStoreStatus\x10\x01\x12\x34\n0HasOriginalStreamVodSmartStrategyDataStoreStatus\x10\x02\x12\x32\n.HasEncodeStreamVodSmartStrategyDataStoreStatus\x10\x03\x42\xd4\x01\n)com.volcengine.service.vod.model.businessB\x10VodSmartStrategyP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_VODSMARTSTRATEGYRESPONSESTREAMTYPE = DESCRIPTOR.enum_types_by_name['VodSmartStrategyResponseStreamType']
VodSmartStrategyResponseStreamType = enum_type_wrapper.EnumTypeWrapper(_VODSMARTSTRATEGYRESPONSESTREAMTYPE)
_VODSMARTSTRATEGYDATASTORESTATUS = DESCRIPTOR.enum_types_by_name['VodSmartStrategyDataStoreStatus']
VodSmartStrategyDataStoreStatus = enum_type_wrapper.EnumTypeWrapper(_VODSMARTSTRATEGYDATASTORESTATUS)
UndefinedVodSmartStrategyResponseStreamType = 0
OriginalStreamVodSmartStrategyResponseStreamType = 1
StrategyEncodeStreamVodSmartStrategyResponseStreamType = 2
FallbackEncodeStreamVodSmartStrategyResponseStreamType = 3
UndefinedVodSmartStrategyDataStoreStatus = 0
NotExistVodSmartStrategyDataStoreStatus = 1
HasOriginalStreamVodSmartStrategyDataStoreStatus = 2
HasEncodeStreamVodSmartStrategyDataStoreStatus = 3


_VODGETSMARTSTRATEGYLITEPLAYINFORESULT = DESCRIPTOR.message_types_by_name['VodGetSmartStrategyLitePlayInfoResult']
VodGetSmartStrategyLitePlayInfoResult = _reflection.GeneratedProtocolMessageType('VodGetSmartStrategyLitePlayInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSMARTSTRATEGYLITEPLAYINFORESULT,
  '__module__' : 'vod.business.vod_smart_strategy_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetSmartStrategyLitePlayInfoResult)
  })
_sym_db.RegisterMessage(VodGetSmartStrategyLitePlayInfoResult)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\020VodSmartStrategyP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODSMARTSTRATEGYRESPONSESTREAMTYPE._serialized_start=423
  _VODSMARTSTRATEGYRESPONSESTREAMTYPE._serialized_end=682
  _VODSMARTSTRATEGYDATASTORESTATUS._serialized_start=685
  _VODSMARTSTRATEGYDATASTORESTATUS._serialized_end=915
  _VODGETSMARTSTRATEGYLITEPLAYINFORESULT._serialized_start=105
  _VODGETSMARTSTRATEGYLITEPLAYINFORESULT._serialized_end=420
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_media.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvod/business/vod_media.proto\x12\x1eVolcengine.Vod.Models.Business\x1a\x1dvod/business/vod_common.proto\"\xee\x01\n\x11VodMediaBasicInfo\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\r\n\x05Title\x18\x03 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x04 \x01(\t\x12\x11\n\tPosterUri\x18\x05 \x01(\t\x12\x15\n\rPublishStatus\x18\x06 \x01(\t\x12\x0c\n\x04Tags\x18\x07 \x03(\t\x12\x12\n\nCreateTime\x18\x08 \x01(\t\x12I\n\x0e\x43lassification\x18\t \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodClassification\"\xe1\x01\n\x0cVodMediaInfo\x12\x44\n\tBasicInfo\x18\x01 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodMediaBasicInfo\x12\x41\n\nSourceInfo\x18\x02 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12H\n\x0eTranscodeInfos\x18\x03 \x03(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodTranscodeInfo\"q\n\x14VodGetMediaInfosData\x12\x43\n\rMediaInfoList\x18\x01 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodMediaInfo\x12\x14\n\x0cNotExistVids\x18\x02 \x03(\t\"2\n\x10VodStoreUriGroup\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x11\n\tStoreUris\x18\x02 \x03(\t\"u\n\x13VodGetRecPosterData\x12H\n\x0eStoreUriGroups\x18\x01 \x03(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodStoreUriGroup\x12\x14\n\x0cNotExistVids\x18\x02 \x03(\t\"*\n\x12VodDeleteMediaData\x12\x14\n\x0cNotExistVids\x18\x01 \x03(\t\"2\n\x17VodDeleteTranscodesData\x12\x17\n\x0fNotExistFileIds\x18\x01 \x03(\t\"\xa3\x01\n\x13VodGetMediaListData\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x43\n\rMediaInfoList\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodMediaInfo\x12\x12\n\nTotalCount\x18\x03 \x01(\x05\x12\x0e\n\x06Offset\x18\x04 \x01(\x05\x12\x10\n\x08PageSize\x18\x05 \x01(\x05\"6\n\x1bVodUpdateSubtitleStatusData\x12\x17\n\x0fNotExistFileIds\x18\x01 \x03(\t\"p\n\x13VodFileSubtitleInfo\x12\x0e\n\x06\x46ileId\x18\x01 \x01(\t\x12I\n\x10SubtitleInfoList\x18\x02 \x03(\x0b\x32/.Volcengine.Vod.Models.Business.VodSubtitleInfo\"\xcb\x01\n\x1aVodGetSubtitleInfoListData\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12Q\n\x14\x46ileSubtitleInfoList\x18\x02 \x03(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodFileSubtitleInfo\x12\x17\n\x0fNotExistFileIds\x18\x03 \x03(\t\x12\x12\n\nTotalCount\x18\x04 \x01(\x05\x12\x0e\n\x06Offset\x18\x05 \x01(\x05\x12\x10\n\x08PageSize\x18\x06 \x01(\x05\"q\n\x14VodFrameDataForAudit\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x13\n\x0b\x46rameNumber\x18\x02 \x01(\x05\x12\x13\n\x0b\x43utTimeMill\x18\x03 \x01(\x01\x12\r\n\x05Width\x18\x04 \x01(\x05\x12\x0e\n\x06Height\x18\x05 \x01(\x05\"b\n\x1aVodGetFramesForAuditResult\x12\x44\n\x06\x46rames\x18\x01 \x03(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodFrameDataForAudit\"\x9f\x01\n\x1aVodBetterFrameDataForAudit\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x13\n\x0b\x46rameNumber\x18\x02 \x01(\x05\x12\x13\n\x0b\x43utTimeMill\x18\x03 \x01(\x01\x12\r\n\x05Width\x18\x04 \x01(\x05\x12\x0e\n\x06Height\x18\x05 \x01(\x05\x12\x11\n\tCoverRate\x18\x06 \x01(\x01\x12\x13\n\x0bLBPHashCode\x18\x07 \x03(\x01\"n\n VodGetBetterFramesForAuditResult\x12J\n\x06\x46rames\x18\x01 \x03(\x0b\x32:.Volcengine.Vod.Models.Business.VodBetterFrameDataForAudit\"J\n\x14VodAudioInfoForAudit\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x10\n\x08\x44uration\x18\x02 \x01(\x01\x12\x0e\n\x06\x46ormat\x18\x03 \x01(\t\"h\n\x1dVodGetAudioInfoForAuditResult\x12G\n\tAudioInfo\x18\x01 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodAudioInfoForAudit\"n\n\x1bVodASRUtteranceWordForAudit\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x15\n\rStartTimeMill\x18\x02 \x01(\x01\x12\x13\n\x0b\x45ndTimeMill\x18\x03 \x01(\x01\x12\x15\n\rBlankDuration\x18\x04 \x01(\x01\"<\n VodCreateVideoClassificationData\x12\x18\n\x10\x43lassificationId\x18\x01 \x01(\x03\"\xbb\x02\n\x11VodClassification\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x02 \x01(\x03\x12\r\n\x05Level\x18\x03 \x01(\x05\x12\x16\n\x0e\x43lassification\x18\x04 \x01(\t\x12\x1e\n\x16ParentClassificationId\x18\x05 \x01(\x03\x12L\n\x11SubClassification\x18\x06 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodClassification\x12Q\n\x16SubClassificationTrees\x18\x07 \x03(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodClassification\x12\x11\n\tCreatedAt\x18\x08 \x01(\t\"m\n\x1bVodVideoClassificationsData\x12N\n\x13\x43lassificationTrees\x18\x01 \x03(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodClassification\"\xc5\x01\n\x17VodASRUtteranceForAudit\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x15\n\rStartTimeMill\x18\x02 \x01(\x01\x12\x13\n\x0b\x45ndTimeMill\x18\x03 \x01(\x01\x12J\n\x05Words\x18\x04 \x03(\x0b\x32;.Volcengine.Vod.Models.Business.VodASRUtteranceWordForAudit\x12\x10\n\x08Language\x18\x05 \x01(\t\x12\x12\n\nSpeechRate\x18\x06 \x01(\x01\">\n\x1cVodASRLanguageDetailForAudit\x12\x0c\n\x04Prob\x18\x01 \x01(\x01\x12\x10\n\x08Language\x18\x02 \x01(\t\"\xfc\x01\n\x12VodASRInfoForAudit\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12K\n\nUtterances\x18\x03 \x03(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodASRUtteranceForAudit\x12\x10\n\x08Language\x18\x04 \x01(\t\x12U\n\x0fLanguageDetails\x18\x05 \x03(\x0b\x32<.Volcengine.Vod.Models.Business.VodASRLanguageDetailForAudit\x12\x12\n\nSpeechRate\x18\x06 \x01(\x01\x12\x0e\n\x06Volume\x18\x07 \x01(\x01\"r\n.VodGetAutomaticSpeechRecognitionForAuditResult\x12@\n\x04Info\x18\x01 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodASRInfoForAudit\"S\n\x17VodAEDTimeRangeForAudit\x12\x15\n\rStartTimeMill\x18\x01 \x01(\x01\x12\x13\n\x0b\x45ndTimeMill\x18\x02 \x01(\x01\x12\x0c\n\x04Prob\x18\x03 \x01(\x01\"\x86\x01\n\x17VodAEDEventItemForAudit\x12\r\n\x05\x45vent\x18\x01 \x01(\t\x12\x0f\n\x07UttProb\x18\x02 \x01(\x01\x12K\n\nTimeRanges\x18\x03 \x03(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodAEDTimeRangeForAudit\"a\n\x12VodAEDInfoForAudit\x12K\n\nEventItems\x18\x01 \x03(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodAEDEventItemForAudit\"k\n\'VodGetAudioEventDetectionForAuditResult\x12@\n\x04Info\x18\x01 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodAEDInfoForAudit\"[\n\x0bVodSnapshot\x12\x0e\n\x06\x46ormat\x18\x01 \x01(\t\x12\x0e\n\x06Height\x18\x02 \x01(\x05\x12\r\n\x05Width\x18\x03 \x01(\x05\x12\x10\n\x08StoreUri\x18\x04 \x01(\t\x12\x0b\n\x03Url\x18\x05 \x01(\t\"\xb3\x01\n\x11VodSpriteSnapshot\x12\x0e\n\x06\x46ormat\x18\x01 \x01(\t\x12\x0f\n\x07ImgXLen\x18\x02 \x01(\x05\x12\x0f\n\x07ImgYLen\x18\x03 \x01(\x05\x12\x11\n\tCellWidth\x18\x04 \x01(\x05\x12\x12\n\nCellHeight\x18\x05 \x01(\x05\x12\x10\n\x08Interval\x18\x06 \x01(\x02\x12\x12\n\nCaptureNum\x18\x07 \x01(\x05\x12\x11\n\tStoreUris\x18\x08 \x03(\t\x12\x0c\n\x04Urls\x18\t \x03(\t\"\xa1\x03\n\x0fVodSnapshotData\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\x44\n\x0fPosterSnapshots\x18\x03 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodSnapshot\x12\x45\n\x10\x44ynpostSnapshots\x18\x04 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodSnapshot\x12L\n\x17\x41nimatedPosterSnapshots\x18\x05 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodSnapshot\x12G\n\x12\x41iDynpostSnapshots\x18\x06 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodSnapshot\x12J\n\x0fSpriteSnapshots\x18\x07 \x03(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodSpriteSnapshot*\xd0\x02\n VodFrameExtractingOptionForAudit\x12-\n)UndefinedVodFrameExtractingOptionForAudit\x10\x00\x12\'\n#FpsVodFrameExtractingOptionForAudit\x10\x01\x12\x32\n.NumberOfFramesVodFrameExtractingOptionForAudit\x10\x02\x12,\n(CutTimesVodFrameExtractingOptionForAudit\x10\x03\x12:\n6FpsLimitNumberOfFramesVodFrameExtractingOptionForAudit\x10\x04\x12\x36\n2OnlyFirstLastFrameVodFrameExtractingOptionForAudit\x10\x05\x42\xcc\x01\n)com.volcengine.service.vod.model.businessB\x08VodMediaP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_VODFRAMEEXTRACTINGOPTIONFORAUDIT = DESCRIPTOR.enum_types_by_name['VodFrameExtractingOptionForAudit']
VodFrameExtractingOptionForAudit = enum_type_wrapper.EnumTypeWrapper(_VODFRAMEEXTRACTINGOPTIONFORAUDIT)
UndefinedVodFrameExtractingOptionForAudit = 0
FpsVodFrameExtractingOptionForAudit = 1
NumberOfFramesVodFrameExtractingOptionForAudit = 2
CutTimesVodFrameExtractingOptionForAudit = 3
FpsLimitNumberOfFramesVodFrameExtractingOptionForAudit = 4
OnlyFirstLastFrameVodFrameExtractingOptionForAudit = 5


_VODMEDIABASICINFO = DESCRIPTOR.message_types_by_name['VodMediaBasicInfo']
_VODMEDIAINFO = DESCRIPTOR.message_types_by_name['VodMediaInfo']
_VODGETMEDIAINFOSDATA = DESCRIPTOR.message_types_by_name['VodGetMediaInfosData']
_VODSTOREURIGROUP = DESCRIPTOR.message_types_by_name['VodStoreUriGroup']
_VODGETRECPOSTERDATA = DESCRIPTOR.message_types_by_name['VodGetRecPosterData']
_VODDELETEMEDIADATA = DESCRIPTOR.message_types_by_name['VodDeleteMediaData']
_VODDELETETRANSCODESDATA = DESCRIPTOR.message_types_by_name['VodDeleteTranscodesData']
_VODGETMEDIALISTDATA = DESCRIPTOR.message_types_by_name['VodGetMediaListData']
_VODUPDATESUBTITLESTATUSDATA = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleStatusData']
_VODFILESUBTITLEINFO = DESCRIPTOR.message_types_by_name['VodFileSubtitleInfo']
_VODGETSUBTITLEINFOLISTDATA = DESCRIPTOR.message_types_by_name['VodGetSubtitleInfoListData']
_VODFRAMEDATAFORAUDIT = DESCRIPTOR.message_types_by_name['VodFrameDataForAudit']
_VODGETFRAMESFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetFramesForAuditResult']
_VODBETTERFRAMEDATAFORAUDIT = DESCRIPTOR.message_types_by_name['VodBetterFrameDataForAudit']
_VODGETBETTERFRAMESFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetBetterFramesForAuditResult']
_VODAUDIOINFOFORAUDIT = DESCRIPTOR.message_types_by_name['VodAudioInfoForAudit']
_VODGETAUDIOINFOFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetAudioInfoForAuditResult']
_VODASRUTTERANCEWORDFORAUDIT = DESCRIPTOR.message_types_by_name['VodASRUtteranceWordForAudit']
_VODCREATEVIDEOCLASSIFICATIONDATA = DESCRIPTOR.message_types_by_name['VodCreateVideoClassificationData']
_VODCLASSIFICATION = DESCRIPTOR.message_types_by_name['VodClassification']
_VODVIDEOCLASSIFICATIONSDATA = DESCRIPTOR.message_types_by_name['VodVideoClassificationsData']
_VODASRUTTERANCEFORAUDIT = DESCRIPTOR.message_types_by_name['VodASRUtteranceForAudit']
_VODASRLANGUAGEDETAILFORAUDIT = DESCRIPTOR.message_types_by_name['VodASRLanguageDetailForAudit']
_VODASRINFOFORAUDIT = DESCRIPTOR.message_types_by_name['VodASRInfoForAudit']
_VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetAutomaticSpeechRecognitionForAuditResult']
_VODAEDTIMERANGEFORAUDIT = DESCRIPTOR.message_types_by_name['VodAEDTimeRangeForAudit']
_VODAEDEVENTITEMFORAUDIT = DESCRIPTOR.message_types_by_name['VodAEDEventItemForAudit']
_VODAEDINFOFORAUDIT = DESCRIPTOR.message_types_by_name['VodAEDInfoForAudit']
_VODGETAUDIOEVENTDETECTIONFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetAudioEventDetectionForAuditResult']
_VODSNAPSHOT = DESCRIPTOR.message_types_by_name['VodSnapshot']
_VODSPRITESNAPSHOT = DESCRIPTOR.message_types_by_name['VodSpriteSnapshot']
_VODSNAPSHOTDATA = DESCRIPTOR.message_types_by_name['VodSnapshotData']
VodMediaBasicInfo = _reflection.GeneratedProtocolMessageType('VodMediaBasicInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODMEDIABASICINFO,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodMediaBasicInfo)
  })
_sym_db.RegisterMessage(VodMediaBasicInfo)

VodMediaInfo = _reflection.GeneratedProtocolMessageType('VodMediaInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODMEDIAINFO,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodMediaInfo)
  })
_sym_db.RegisterMessage(VodMediaInfo)

VodGetMediaInfosData = _reflection.GeneratedProtocolMessageType('VodGetMediaInfosData', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIAINFOSDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetMediaInfosData)
  })
_sym_db.RegisterMessage(VodGetMediaInfosData)

VodStoreUriGroup = _reflection.GeneratedProtocolMessageType('VodStoreUriGroup', (_message.Message,), {
  'DESCRIPTOR' : _VODSTOREURIGROUP,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodStoreUriGroup)
  })
_sym_db.RegisterMessage(VodStoreUriGroup)

VodGetRecPosterData = _reflection.GeneratedProtocolMessageType('VodGetRecPosterData', (_message.Message,), {
  'DESCRIPTOR' : _VODGETRECPOSTERDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetRecPosterData)
  })
_sym_db.RegisterMessage(VodGetRecPosterData)

VodDeleteMediaData = _reflection.GeneratedProtocolMessageType('VodDeleteMediaData', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEMEDIADATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodDeleteMediaData)
  })
_sym_db.RegisterMessage(VodDeleteMediaData)

VodDeleteTranscodesData = _reflection.GeneratedProtocolMessageType('VodDeleteTranscodesData', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETETRANSCODESDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodDeleteTranscodesData)
  })
_sym_db.RegisterMessage(VodDeleteTranscodesData)

VodGetMediaListData = _reflection.GeneratedProtocolMessageType('VodGetMediaListData', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIALISTDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetMediaListData)
  })
_sym_db.RegisterMessage(VodGetMediaListData)

VodUpdateSubtitleStatusData = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleStatusData', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLESTATUSDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUpdateSubtitleStatusData)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleStatusData)

VodFileSubtitleInfo = _reflection.GeneratedProtocolMessageType('VodFileSubtitleInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODFILESUBTITLEINFO,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodFileSubtitleInfo)
  })
_sym_db.RegisterMessage(VodFileSubtitleInfo)

VodGetSubtitleInfoListData = _reflection.GeneratedProtocolMessageType('VodGetSubtitleInfoListData', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSUBTITLEINFOLISTDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetSubtitleInfoListData)
  })
_sym_db.RegisterMessage(VodGetSubtitleInfoListData)

VodFrameDataForAudit = _reflection.GeneratedProtocolMessageType('VodFrameDataForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODFRAMEDATAFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodFrameDataForAudit)
  })
_sym_db.RegisterMessage(VodFrameDataForAudit)

VodGetFramesForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetFramesForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETFRAMESFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetFramesForAuditResult)
  })
_sym_db.RegisterMessage(VodGetFramesForAuditResult)

VodBetterFrameDataForAudit = _reflection.GeneratedProtocolMessageType('VodBetterFrameDataForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODBETTERFRAMEDATAFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodBetterFrameDataForAudit)
  })
_sym_db.RegisterMessage(VodBetterFrameDataForAudit)

VodGetBetterFramesForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetBetterFramesForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETBETTERFRAMESFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetBetterFramesForAuditResult)
  })
_sym_db.RegisterMessage(VodGetBetterFramesForAuditResult)

VodAudioInfoForAudit = _reflection.GeneratedProtocolMessageType('VodAudioInfoForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODAUDIOINFOFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAudioInfoForAudit)
  })
_sym_db.RegisterMessage(VodAudioInfoForAudit)

VodGetAudioInfoForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetAudioInfoForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOINFOFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetAudioInfoForAuditResult)
  })
_sym_db.RegisterMessage(VodGetAudioInfoForAuditResult)

VodASRUtteranceWordForAudit = _reflection.GeneratedProtocolMessageType('VodASRUtteranceWordForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODASRUTTERANCEWORDFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodASRUtteranceWordForAudit)
  })
_sym_db.RegisterMessage(VodASRUtteranceWordForAudit)

VodCreateVideoClassificationData = _reflection.GeneratedProtocolMessageType('VodCreateVideoClassificationData', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEVIDEOCLASSIFICATIONDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCreateVideoClassificationData)
  })
_sym_db.RegisterMessage(VodCreateVideoClassificationData)

VodClassification = _reflection.GeneratedProtocolMessageType('VodClassification', (_message.Message,), {
  'DESCRIPTOR' : _VODCLASSIFICATION,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodClassification)
  })
_sym_db.RegisterMessage(VodClassification)

VodVideoClassificationsData = _reflection.GeneratedProtocolMessageType('VodVideoClassificationsData', (_message.Message,), {
  'DESCRIPTOR' : _VODVIDEOCLASSIFICATIONSDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodVideoClassificationsData)
  })
_sym_db.RegisterMessage(VodVideoClassificationsData)

VodASRUtteranceForAudit = _reflection.GeneratedProtocolMessageType('VodASRUtteranceForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODASRUTTERANCEFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodASRUtteranceForAudit)
  })
_sym_db.RegisterMessage(VodASRUtteranceForAudit)

VodASRLanguageDetailForAudit = _reflection.GeneratedProtocolMessageType('VodASRLanguageDetailForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODASRLANGUAGEDETAILFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodASRLanguageDetailForAudit)
  })
_sym_db.RegisterMessage(VodASRLanguageDetailForAudit)

VodASRInfoForAudit = _reflection.GeneratedProtocolMessageType('VodASRInfoForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODASRINFOFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodASRInfoForAudit)
  })
_sym_db.RegisterMessage(VodASRInfoForAudit)

VodGetAutomaticSpeechRecognitionForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetAutomaticSpeechRecognitionForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetAutomaticSpeechRecognitionForAuditResult)
  })
_sym_db.RegisterMessage(VodGetAutomaticSpeechRecognitionForAuditResult)

VodAEDTimeRangeForAudit = _reflection.GeneratedProtocolMessageType('VodAEDTimeRangeForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODAEDTIMERANGEFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAEDTimeRangeForAudit)
  })
_sym_db.RegisterMessage(VodAEDTimeRangeForAudit)

VodAEDEventItemForAudit = _reflection.GeneratedProtocolMessageType('VodAEDEventItemForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODAEDEVENTITEMFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAEDEventItemForAudit)
  })
_sym_db.RegisterMessage(VodAEDEventItemForAudit)

VodAEDInfoForAudit = _reflection.GeneratedProtocolMessageType('VodAEDInfoForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODAEDINFOFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAEDInfoForAudit)
  })
_sym_db.RegisterMessage(VodAEDInfoForAudit)

VodGetAudioEventDetectionForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetAudioEventDetectionForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOEVENTDETECTIONFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetAudioEventDetectionForAuditResult)
  })
_sym_db.RegisterMessage(VodGetAudioEventDetectionForAuditResult)

VodSnapshot = _reflection.GeneratedProtocolMessageType('VodSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _VODSNAPSHOT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSnapshot)
  })
_sym_db.RegisterMessage(VodSnapshot)

VodSpriteSnapshot = _reflection.GeneratedProtocolMessageType('VodSpriteSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _VODSPRITESNAPSHOT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSpriteSnapshot)
  })
_sym_db.RegisterMessage(VodSpriteSnapshot)

VodSnapshotData = _reflection.GeneratedProtocolMessageType('VodSnapshotData', (_message.Message,), {
  'DESCRIPTOR' : _VODSNAPSHOTDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSnapshotData)
  })
_sym_db.RegisterMessage(VodSnapshotData)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\010VodMediaP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODFRAMEEXTRACTINGOPTIONFORAUDIT._serialized_start=4523
  _VODFRAMEEXTRACTINGOPTIONFORAUDIT._serialized_end=4859
  _VODMEDIABASICINFO._serialized_start=96
  _VODMEDIABASICINFO._serialized_end=334
  _VODMEDIAINFO._serialized_start=337
  _VODMEDIAINFO._serialized_end=562
  _VODGETMEDIAINFOSDATA._serialized_start=564
  _VODGETMEDIAINFOSDATA._serialized_end=677
  _VODSTOREURIGROUP._serialized_start=679
  _VODSTOREURIGROUP._serialized_end=729
  _VODGETRECPOSTERDATA._serialized_start=731
  _VODGETRECPOSTERDATA._serialized_end=848
  _VODDELETEMEDIADATA._serialized_start=850
  _VODDELETEMEDIADATA._serialized_end=892
  _VODDELETETRANSCODESDATA._serialized_start=894
  _VODDELETETRANSCODESDATA._serialized_end=944
  _VODGETMEDIALISTDATA._serialized_start=947
  _VODGETMEDIALISTDATA._serialized_end=1110
  _VODUPDATESUBTITLESTATUSDATA._serialized_start=1112
  _VODUPDATESUBTITLESTATUSDATA._serialized_end=1166
  _VODFILESUBTITLEINFO._serialized_start=1168
  _VODFILESUBTITLEINFO._serialized_end=1280
  _VODGETSUBTITLEINFOLISTDATA._serialized_start=1283
  _VODGETSUBTITLEINFOLISTDATA._serialized_end=1486
  _VODFRAMEDATAFORAUDIT._serialized_start=1488
  _VODFRAMEDATAFORAUDIT._serialized_end=1601
  _VODGETFRAMESFORAUDITRESULT._serialized_start=1603
  _VODGETFRAMESFORAUDITRESULT._serialized_end=1701
  _VODBETTERFRAMEDATAFORAUDIT._serialized_start=1704
  _VODBETTERFRAMEDATAFORAUDIT._serialized_end=1863
  _VODGETBETTERFRAMESFORAUDITRESULT._serialized_start=1865
  _VODGETBETTERFRAMESFORAUDITRESULT._serialized_end=1975
  _VODAUDIOINFOFORAUDIT._serialized_start=1977
  _VODAUDIOINFOFORAUDIT._serialized_end=2051
  _VODGETAUDIOINFOFORAUDITRESULT._serialized_start=2053
  _VODGETAUDIOINFOFORAUDITRESULT._serialized_end=2157
  _VODASRUTTERANCEWORDFORAUDIT._serialized_start=2159
  _VODASRUTTERANCEWORDFORAUDIT._serialized_end=2269
  _VODCREATEVIDEOCLASSIFICATIONDATA._serialized_start=2271
  _VODCREATEVIDEOCLASSIFICATIONDATA._serialized_end=2331
  _VODCLASSIFICATION._serialized_start=2334
  _VODCLASSIFICATION._serialized_end=2649
  _VODVIDEOCLASSIFICATIONSDATA._serialized_start=2651
  _VODVIDEOCLASSIFICATIONSDATA._serialized_end=2760
  _VODASRUTTERANCEFORAUDIT._serialized_start=2763
  _VODASRUTTERANCEFORAUDIT._serialized_end=2960
  _VODASRLANGUAGEDETAILFORAUDIT._serialized_start=2962
  _VODASRLANGUAGEDETAILFORAUDIT._serialized_end=3024
  _VODASRINFOFORAUDIT._serialized_start=3027
  _VODASRINFOFORAUDIT._serialized_end=3279
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESULT._serialized_start=3281
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESULT._serialized_end=3395
  _VODAEDTIMERANGEFORAUDIT._serialized_start=3397
  _VODAEDTIMERANGEFORAUDIT._serialized_end=3480
  _VODAEDEVENTITEMFORAUDIT._serialized_start=3483
  _VODAEDEVENTITEMFORAUDIT._serialized_end=3617
  _VODAEDINFOFORAUDIT._serialized_start=3619
  _VODAEDINFOFORAUDIT._serialized_end=3716
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESULT._serialized_start=3718
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESULT._serialized_end=3825
  _VODSNAPSHOT._serialized_start=3827
  _VODSNAPSHOT._serialized_end=3918
  _VODSPRITESNAPSHOT._serialized_start=3921
  _VODSPRITESNAPSHOT._serialized_end=4100
  _VODSNAPSHOTDATA._serialized_start=4103
  _VODSNAPSHOTDATA._serialized_end=4520
# @@protoc_insertion_point(module_scope)



# coding:utf-8
import datetime
from collections import OrderedDict


class SignParam(object):
    def __init__(self):
        self.body = ''
        self.query = OrderedDict()
        self.date = datetime.datetime.now()
        self.header_list = OrderedDict()
        self.is_sign_url = False
        self.host = ''
        self.path = '/'
        self.method = ''

    def set_date(self, date):
        self.date = date

    def set_body(self, body):
        self.body = body

    def set_host(self, host):
        self.host = host

    def set_query(self, query):
        self.query = query

    def set_header_list(self, header_list):
        self.header_list = header_list

    def set_is_sign_url(self, is_sign_url):
        self.is_sign_url = is_sign_url

    def set_path(self, path):
        self.path = path

    def set_method(self, method):
        self.method = method







# coding:utf-8
from __future__ import print_function

import json

from volcengine.util.Functions import Function
from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodUploadMediaRequest

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')

    space_name = 'your space name'
    file_path = 'your file path'

    get_meta_function = Function.get_meta_func()
    snapshot_function = Function.get_snapshot_func(2.3)

    try:
        req = VodUploadMediaRequest()
        req.SpaceName = space_name
        req.FilePath = file_path
        req.Functions = json.dumps([get_meta_function, snapshot_function])
        req.CallbackArgs = ''
        req.FileName = ''

        resp = vod_service.upload_media(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result.Data)
            print(resp.Result.Data.Vid)
            print(resp.Result.Data.PosterUri)
            print(resp.Result.Data.SourceInfo.Height)
            print(resp.Result.Data.SourceInfo.Width)
        else:
            print(resp.ResponseMetadata.Error)
            print(resp.ResponseMetadata.RequestId)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvod/business/vod_space.proto\x12\x1eVolcengine.Vod.Models.Business\"\xd0\x01\n\x0cVodSpaceInfo\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0e\n\x06Region\x18\x03 \x01(\t\x12\x13\n\x0bProjectName\x18\x04 \x01(\t\x12\x12\n\nBucketName\x18\x05 \x01(\t\x12\x14\n\x0c\x42ucketStatus\x18\x06 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x07 \x01(\t\x12\x10\n\x08UserName\x18\x08 \x01(\t\x12\x11\n\tCreatedAt\x18\t \x01(\t\x12\x0c\n\x04Type\x18\n \x01(\t\x12\x16\n\x0eMediaSyncLevel\x18\x0b \x01(\t*\xa3\x01\n\x17VodSpaceUploadConfigKey\x12$\n UndefinedVodSpaceUploadConfigKey\x10\x00\x12/\n+CustomUploadFilePathVodSpaceUploadConfigKey\x10\x01\x12\x31\n-AutoPublishAfterUploadVodSpaceUploadConfigKey\x10\x02\x42\xcc\x01\n)com.volcengine.service.vod.model.businessB\x08VodSpaceP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_VODSPACEUPLOADCONFIGKEY = DESCRIPTOR.enum_types_by_name['VodSpaceUploadConfigKey']
VodSpaceUploadConfigKey = enum_type_wrapper.EnumTypeWrapper(_VODSPACEUPLOADCONFIGKEY)
UndefinedVodSpaceUploadConfigKey = 0
CustomUploadFilePathVodSpaceUploadConfigKey = 1
AutoPublishAfterUploadVodSpaceUploadConfigKey = 2


_VODSPACEINFO = DESCRIPTOR.message_types_by_name['VodSpaceInfo']
VodSpaceInfo = _reflection.GeneratedProtocolMessageType('VodSpaceInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODSPACEINFO,
  '__module__' : 'vod.business.vod_space_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSpaceInfo)
  })
_sym_db.RegisterMessage(VodSpaceInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\010VodSpaceP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODSPACEUPLOADCONFIGKEY._serialized_start=276
  _VODSPACEUPLOADCONFIGKEY._serialized_end=439
  _VODSPACEINFO._serialized_start=65
  _VODSPACEINFO._serialized_end=273
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_workflow.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvod/business/vod_workflow.proto\x12\x1eVolcengine.Vod.Models.Business\"\'\n\x16VodStartWorkflowResult\x12\r\n\x05RunId\x18\x01 \x01(\t\"\xdc\x01\n\x0eWorkflowParams\x12\x46\n\x0eOverrideParams\x18\x01 \x01(\x0b\x32..Volcengine.Vod.Models.Business.OverrideParams\x12P\n\tCondition\x18\x02 \x03(\x0b\x32=.Volcengine.Vod.Models.Business.WorkflowParams.ConditionEntry\x1a\x30\n\x0e\x43onditionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xb0\x02\n\x0eOverrideParams\x12:\n\x04Logo\x18\x01 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.LogoOverride\x12N\n\x0eTranscodeVideo\x18\x02 \x03(\x0b\x32\x36.Volcengine.Vod.Models.Business.TranscodeVideoOverride\x12N\n\x0eTranscodeAudio\x18\x03 \x03(\x0b\x32\x36.Volcengine.Vod.Models.Business.TranscodeAudioOverride\x12\x42\n\x08Snapshot\x18\x04 \x03(\x0b\x32\x30.Volcengine.Vod.Models.Business.SnapshotOverride\"\x95\x01\n\x0cLogoOverride\x12\x12\n\nTemplateId\x18\x01 \x01(\t\x12\x44\n\x04Vars\x18\x02 \x03(\x0b\x32\x36.Volcengine.Vod.Models.Business.LogoOverride.VarsEntry\x1a+\n\tVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x16TranscodeVideoOverride\x12\x12\n\nTemplateId\x18\x01 \x03(\t\x12\x32\n\x04\x43lip\x18\x02 \x01(\x0b\x32$.Volcengine.Vod.Models.Business.Clip\"*\n\x04\x43lip\x12\x11\n\tStartTime\x18\x01 \x01(\x05\x12\x0f\n\x07\x45ndTime\x18\x02 \x01(\x05\"`\n\x16TranscodeAudioOverride\x12\x12\n\nTemplateId\x18\x01 \x03(\t\x12\x32\n\x04\x43lip\x18\x02 \x01(\x0b\x32$.Volcengine.Vod.Models.Business.Clip\"R\n\x10SnapshotOverride\x12\x12\n\nTemplateId\x18\x01 \x03(\t\x12\x12\n\nOffsetTime\x18\x02 \x01(\x05\x12\x16\n\x0eOffsetTimeList\x18\x03 \x03(\x05\"\xa5\x01\n\x0fTranscodeResult\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12>\n\nInspection\x18\x02 \x01(\x0b\x32*.Volcengine.Vod.Models.Business.Inspection\x12\x45\n\x0c\x43\x61tegoryTags\x18\x03 \x03(\x0b\x32/.Volcengine.Vod.Models.Business.CategoryTagInfo\"\x82\x01\n\nInspection\x12\x38\n\x07Quality\x18\x01 \x01(\x0b\x32\'.Volcengine.Vod.Models.Business.Quality\x12:\n\x06\x44\x65Logo\x18\x02 \x03(\x0b\x32*.Volcengine.Vod.Models.Business.DeLogoInfo\"\x88\x01\n\x07Quality\x12=\n\x06Visual\x18\x01 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VisualQuality\x12>\n\nVolumeInfo\x18\x02 \x01(\x0b\x32*.Volcengine.Vod.Models.Business.VolumeInfo\"q\n\nDeLogoInfo\x12\x13\n\x0b\x41nchorWidth\x18\x01 \x01(\x03\x12\x14\n\x0c\x41nchorHeight\x18\x02 \x01(\x03\x12\x0c\n\x04PosX\x18\x03 \x01(\x03\x12\x0c\n\x04PosY\x18\x04 \x01(\x03\x12\r\n\x05SizeX\x18\x05 \x01(\x03\x12\r\n\x05SizeY\x18\x06 \x01(\x03\"|\n\rVisualQuality\x12\x0f\n\x07VQScore\x18\x01 \x01(\x01\x12\x10\n\x08\x43ontrast\x18\x02 \x01(\x01\x12\x14\n\x0c\x43olorfulness\x18\x03 \x01(\x01\x12\x12\n\nBrightness\x18\x04 \x01(\x01\x12\x0f\n\x07Texture\x18\x05 \x01(\x01\x12\r\n\x05Noise\x18\x06 \x01(\x01\"S\n\nVolumeInfo\x12\x10\n\x08Loudness\x18\x01 \x01(\x01\x12\x0c\n\x04Peak\x18\x02 \x01(\x01\x12\x12\n\nMeanVolume\x18\x03 \x01(\x01\x12\x11\n\tMaxVolume\x18\x04 \x01(\x01\"\xd6\x01\n\x0f\x43\x61tegoryTagInfo\x12\r\n\x05TagId\x18\x01 \x01(\x03\x12\x0c\n\x04Prob\x18\x02 \x01(\x01\x12\x0f\n\x07TagName\x18\x03 \x01(\t\x12\r\n\x05Level\x18\x04 \x01(\x03\x12S\n\nParentInfo\x18\x05 \x03(\x0b\x32?.Volcengine.Vod.Models.Business.CategoryTagInfo.ParentInfoEntry\x1a\x31\n\x0fParentInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\xcc\x01\n)com.volcengine.service.vod.model.businessB\x0bVodWorkflowP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODSTARTWORKFLOWRESULT = DESCRIPTOR.message_types_by_name['VodStartWorkflowResult']
_WORKFLOWPARAMS = DESCRIPTOR.message_types_by_name['WorkflowParams']
_WORKFLOWPARAMS_CONDITIONENTRY = _WORKFLOWPARAMS.nested_types_by_name['ConditionEntry']
_OVERRIDEPARAMS = DESCRIPTOR.message_types_by_name['OverrideParams']
_LOGOOVERRIDE = DESCRIPTOR.message_types_by_name['LogoOverride']
_LOGOOVERRIDE_VARSENTRY = _LOGOOVERRIDE.nested_types_by_name['VarsEntry']
_TRANSCODEVIDEOOVERRIDE = DESCRIPTOR.message_types_by_name['TranscodeVideoOverride']
_CLIP = DESCRIPTOR.message_types_by_name['Clip']
_TRANSCODEAUDIOOVERRIDE = DESCRIPTOR.message_types_by_name['TranscodeAudioOverride']
_SNAPSHOTOVERRIDE = DESCRIPTOR.message_types_by_name['SnapshotOverride']
_TRANSCODERESULT = DESCRIPTOR.message_types_by_name['TranscodeResult']
_INSPECTION = DESCRIPTOR.message_types_by_name['Inspection']
_QUALITY = DESCRIPTOR.message_types_by_name['Quality']
_DELOGOINFO = DESCRIPTOR.message_types_by_name['DeLogoInfo']
_VISUALQUALITY = DESCRIPTOR.message_types_by_name['VisualQuality']
_VOLUMEINFO = DESCRIPTOR.message_types_by_name['VolumeInfo']
_CATEGORYTAGINFO = DESCRIPTOR.message_types_by_name['CategoryTagInfo']
_CATEGORYTAGINFO_PARENTINFOENTRY = _CATEGORYTAGINFO.nested_types_by_name['ParentInfoEntry']
VodStartWorkflowResult = _reflection.GeneratedProtocolMessageType('VodStartWorkflowResult', (_message.Message,), {
  'DESCRIPTOR' : _VODSTARTWORKFLOWRESULT,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodStartWorkflowResult)
  })
_sym_db.RegisterMessage(VodStartWorkflowResult)

WorkflowParams = _reflection.GeneratedProtocolMessageType('WorkflowParams', (_message.Message,), {

  'ConditionEntry' : _reflection.GeneratedProtocolMessageType('ConditionEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKFLOWPARAMS_CONDITIONENTRY,
    '__module__' : 'vod.business.vod_workflow_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.WorkflowParams.ConditionEntry)
    })
  ,
  'DESCRIPTOR' : _WORKFLOWPARAMS,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.WorkflowParams)
  })
_sym_db.RegisterMessage(WorkflowParams)
_sym_db.RegisterMessage(WorkflowParams.ConditionEntry)

OverrideParams = _reflection.GeneratedProtocolMessageType('OverrideParams', (_message.Message,), {
  'DESCRIPTOR' : _OVERRIDEPARAMS,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.OverrideParams)
  })
_sym_db.RegisterMessage(OverrideParams)

LogoOverride = _reflection.GeneratedProtocolMessageType('LogoOverride', (_message.Message,), {

  'VarsEntry' : _reflection.GeneratedProtocolMessageType('VarsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGOOVERRIDE_VARSENTRY,
    '__module__' : 'vod.business.vod_workflow_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.LogoOverride.VarsEntry)
    })
  ,
  'DESCRIPTOR' : _LOGOOVERRIDE,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.LogoOverride)
  })
_sym_db.RegisterMessage(LogoOverride)
_sym_db.RegisterMessage(LogoOverride.VarsEntry)

TranscodeVideoOverride = _reflection.GeneratedProtocolMessageType('TranscodeVideoOverride', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCODEVIDEOOVERRIDE,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.TranscodeVideoOverride)
  })
_sym_db.RegisterMessage(TranscodeVideoOverride)

Clip = _reflection.GeneratedProtocolMessageType('Clip', (_message.Message,), {
  'DESCRIPTOR' : _CLIP,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.Clip)
  })
_sym_db.RegisterMessage(Clip)

TranscodeAudioOverride = _reflection.GeneratedProtocolMessageType('TranscodeAudioOverride', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCODEAUDIOOVERRIDE,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.TranscodeAudioOverride)
  })
_sym_db.RegisterMessage(TranscodeAudioOverride)

SnapshotOverride = _reflection.GeneratedProtocolMessageType('SnapshotOverride', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTOVERRIDE,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.SnapshotOverride)
  })
_sym_db.RegisterMessage(SnapshotOverride)

TranscodeResult = _reflection.GeneratedProtocolMessageType('TranscodeResult', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCODERESULT,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.TranscodeResult)
  })
_sym_db.RegisterMessage(TranscodeResult)

Inspection = _reflection.GeneratedProtocolMessageType('Inspection', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTION,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.Inspection)
  })
_sym_db.RegisterMessage(Inspection)

Quality = _reflection.GeneratedProtocolMessageType('Quality', (_message.Message,), {
  'DESCRIPTOR' : _QUALITY,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.Quality)
  })
_sym_db.RegisterMessage(Quality)

DeLogoInfo = _reflection.GeneratedProtocolMessageType('DeLogoInfo', (_message.Message,), {
  'DESCRIPTOR' : _DELOGOINFO,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DeLogoInfo)
  })
_sym_db.RegisterMessage(DeLogoInfo)

VisualQuality = _reflection.GeneratedProtocolMessageType('VisualQuality', (_message.Message,), {
  'DESCRIPTOR' : _VISUALQUALITY,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VisualQuality)
  })
_sym_db.RegisterMessage(VisualQuality)

VolumeInfo = _reflection.GeneratedProtocolMessageType('VolumeInfo', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMEINFO,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VolumeInfo)
  })
_sym_db.RegisterMessage(VolumeInfo)

CategoryTagInfo = _reflection.GeneratedProtocolMessageType('CategoryTagInfo', (_message.Message,), {

  'ParentInfoEntry' : _reflection.GeneratedProtocolMessageType('ParentInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _CATEGORYTAGINFO_PARENTINFOENTRY,
    '__module__' : 'vod.business.vod_workflow_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.CategoryTagInfo.ParentInfoEntry)
    })
  ,
  'DESCRIPTOR' : _CATEGORYTAGINFO,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.CategoryTagInfo)
  })
_sym_db.RegisterMessage(CategoryTagInfo)
_sym_db.RegisterMessage(CategoryTagInfo.ParentInfoEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\013VodWorkflowP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _WORKFLOWPARAMS_CONDITIONENTRY._options = None
  _WORKFLOWPARAMS_CONDITIONENTRY._serialized_options = b'8\001'
  _LOGOOVERRIDE_VARSENTRY._options = None
  _LOGOOVERRIDE_VARSENTRY._serialized_options = b'8\001'
  _CATEGORYTAGINFO_PARENTINFOENTRY._options = None
  _CATEGORYTAGINFO_PARENTINFOENTRY._serialized_options = b'8\001'
  _VODSTARTWORKFLOWRESULT._serialized_start=67
  _VODSTARTWORKFLOWRESULT._serialized_end=106
  _WORKFLOWPARAMS._serialized_start=109
  _WORKFLOWPARAMS._serialized_end=329
  _WORKFLOWPARAMS_CONDITIONENTRY._serialized_start=281
  _WORKFLOWPARAMS_CONDITIONENTRY._serialized_end=329
  _OVERRIDEPARAMS._serialized_start=332
  _OVERRIDEPARAMS._serialized_end=636
  _LOGOOVERRIDE._serialized_start=639
  _LOGOOVERRIDE._serialized_end=788
  _LOGOOVERRIDE_VARSENTRY._serialized_start=745
  _LOGOOVERRIDE_VARSENTRY._serialized_end=788
  _TRANSCODEVIDEOOVERRIDE._serialized_start=790
  _TRANSCODEVIDEOOVERRIDE._serialized_end=886
  _CLIP._serialized_start=888
  _CLIP._serialized_end=930
  _TRANSCODEAUDIOOVERRIDE._serialized_start=932
  _TRANSCODEAUDIOOVERRIDE._serialized_end=1028
  _SNAPSHOTOVERRIDE._serialized_start=1030
  _SNAPSHOTOVERRIDE._serialized_end=1112
  _TRANSCODERESULT._serialized_start=1115
  _TRANSCODERESULT._serialized_end=1280
  _INSPECTION._serialized_start=1283
  _INSPECTION._serialized_end=1413
  _QUALITY._serialized_start=1416
  _QUALITY._serialized_end=1552
  _DELOGOINFO._serialized_start=1554
  _DELOGOINFO._serialized_end=1667
  _VISUALQUALITY._serialized_start=1669
  _VISUALQUALITY._serialized_end=1793
  _VOLUMEINFO._serialized_start=1795
  _VOLUMEINFO._serialized_end=1878
  _CATEGORYTAGINFO._serialized_start=1881
  _CATEGORYTAGINFO._serialized_end=2095
  _CATEGORYTAGINFO_PARENTINFOENTRY._serialized_start=2046
  _CATEGORYTAGINFO_PARENTINFOENTRY._serialized_end=2095
# @@protoc_insertion_point(module_scope)



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService


# 示例 -  查询直播域名带宽数据
def example_describe_live_bandwidth_data(live_service):
    body = {
        "DomainList": ["example.com", "example2.com"],
        "StartTime": "2022-04-13T00:00:00Z",
        "EndTime": "2022-04-14T00:00:00Z",
        "Aggregation": 300,
    }
    resp = live_service.describe_live_bandwidth_data(body)
    print(resp)


# 示例 -  查询直播域名流量数据
def example_describe_live_traffic_data(live_service):
    body = {
        "DomainList": ["example.com", "example2.com"],
        "StartTime": "2022-04-13T00:00:00Z",
        "EndTime": "2022-04-14T00:00:00Z",
        "Aggregation": 300,
    }
    resp = live_service.describe_live_traffic_data(body)
    print(resp)


# 示例 - 查询95带宽
def example_describe_live_P95Peak_bandwidth_data(live_service):
    body = {
        "StartTime": "2022-04-13T00:00:00Z",
        "EndTime": "2022-04-14T00:00:00Z",
        "Aggregation": 300,
    }
    resp = live_service.describe_live_P95Peak_bandwidth_data(body)
    print(resp)


# 示例 -  查询直播域名录制用量
def example_describe_record_data(live_service):
    body = {
        "DomainList": ["example.com", "example2.com"],
        "StartTime": "2022-04-13T00:00:00Z",
        "EndTime": "2022-04-13T00:10:00Z",
        "Aggregation": 300,
    }
    resp = live_service.describe_record_data(body)
    print(resp)


# 示例 -  查询直播域名转码用量
def example_describe_transcode_data(live_service):
    body = {
        "DomainList": ["example.com", "example2.com"],
        "StartTime": "2022-03-07T00:00:00+08:00",
        "EndTime": "2022-03-08T00:00:00+08:00",
        "Aggregation": 86400,
    }
    resp = live_service.describe_transcode_data(body)
    print(resp)


# 示例 -  查询直播域名截图张数
def example_describe_snapshot_data(live_service):
    body = {
        "DomainList": ["example.com", "example2.com"],
        "StartTime": "2022-03-07T00:00:00+08:00",
        "EndTime": "2022-03-08T00:00:00+08:00",
        "Aggregation": 86400,
    }
    resp = live_service.describe_snapshot_data(body)
    print(resp)


# 示例 - 日志下载
def example_describe_live_domain_log(live_service):
    params = {
        "DomainList": ["example.com", "example2.com"],
        "StartTime": "2022-04-21T14:00:00+08:00",
        "EndTime": "2022-04-22T14:00:00+08:00",
    }
    resp = live_service.describe_live_domain_log(params)
    print(resp)


# 示例 - 查询推流监控数据
def example_describe_push_stream_metrics(live_service):
    body = {
        "Domain": "example.com",
        "App": "example_app",
        "Stream": "example_stream",
        "StartTime": "2022-04-21T00:00:00Z",
        "EndTime": "2022-04-23T23:59:59Z",
        "Aggregation": 30,
    }
    resp = live_service.describe_push_stream_metrics(body)
    print(resp)


# 示例 - 查询直播流历史在线人数
def example_describe_live_stream_sessions(live_service):
    body = {
        "Domain": "example.com",
        "App": "example",
        "Stream": "example080601",
        "ProtocolList": ["RTMP", "HTTP-FLV"],
        "StartTime": "2022-04-21T00:00:00Z",
        "EndTime": "2022-04-21T10:59:59Z",
        "Aggregation": 60,
    }
    resp = live_service.describe_live_stream_sessions(body)
    print(resp)


# 示例 -  查询域名 HTTP 返回码占比
def example_describe_play_response_status_stat(live_service):
    body = {
        "DomainList": ["example.com", "example2.com"],
        "StartTime": "2021-08-16T00:00:00Z",
        "EndTime": "2021-08-16T00:01:59Z",
        "Aggregation": 60
    }
    resp = live_service.describe_play_response_status_stat(body)
    print(resp)


# 示例 - Stream流量查询
def example_describe_live_metric_traffic_data(live_service):
    body = {
        "DomainList": ["example.com"],
        "ProtocolList": ["HTTP-FLV", "RTMP"],
        "ISPList": ["telecom"],
        "IPList": ["123.123.123.000"],
        "RegionList": [
            {
                "Area": "cn",
                "Country": "cn",
                "Province": "beijing",
            },
        ],
        "StartTime": "2022-04-13T00:00:00+08:00",
        "EndTime": "2022-04-13T12:00:00+08:00",
        "Aggregation": 300,
        "ShowDetail": True,
    }
    resp = live_service.describe_live_metric_traffic_data(body)
    print(resp)


# 示例 - Stream带宽查询
def example_describe_live_metric_bandwidth_data(live_service):
    body = {
        "DomainList": ["example.com"],
        "ProtocolList": ["HTTP-FLV", "RTMP"],
        "ISPList": ["telecom"],
        "IPList": ["123.123.123.000"],
        "RegionList": [
            {
                "Area": "cn",
                "Country": "cn",
                "Province": "beijing",
            },
        ],
        "StartTime": "2021-04-13T00:00:00+08:00",
        "EndTime": "2021-04-14T00:00:00+08:00",
        "Aggregation": 300,
        "ShowDetail": True,
    }
    resp = live_service.describe_live_metric_bandwidth_data(body)
    print(resp)


# 示例 - 拉流域名查询流列表
def example_describe_play_stream_list(live_service):
    params = {
        "Domain": "example.com",
        "StartTime": "2022-04-13T00:00:00+08:00",
        "EndTime": "2022-04-14T00:00:00+08:00",
    }
    resp = live_service.describe_play_stream_list(params)
    print(resp)


# 示例 - 拉流转推带宽查询
def example_describe_pull_to_push_bandwidth_data(live_service):
    params = {
        "DomainList": ["example.com"],
        "DstAddrTypeList": ["live","Third"],
        "StartTime": "2021-04-13T00:00:00+08:00",
        "EndTime": "2021-04-14T00:00:00+08:00",
        "Aggregation": 300,
        "ShowDetail": True
    }
    resp = live_service.describe_pull_to_push_bandwidth_data(params)
    print(resp)


if __name__ == '__main__':
    live_service = LiveService()
    ak = ""
    sk = ""
    live_service.set_ak(ak)
    live_service.set_sk(sk)
    # 1.查询直播域名带宽数据
    example_describe_live_bandwidth_data(live_service)
    # 2.查询直播域名流量数据
    example_describe_live_traffic_data(live_service)
    # 3.查询95带宽
    example_describe_live_P95Peak_bandwidth_data(live_service)
    # 4.查询直播域名录制用量
    example_describe_record_data(live_service)
    # 5.查询直播域名转码用量
    example_describe_transcode_data(live_service)
    # 6.查询直播域名截图张数
    example_describe_snapshot_data(live_service)
    # 7.日志下载
    example_describe_live_domain_log(live_service)
    # 8.查询推流监控数据
    example_describe_push_stream_metrics(live_service)
    # 9.查询直播流历史在线人数
    example_describe_live_stream_sessions(live_service)
    # 10.查询域名 HTTP 返回码占比
    example_describe_play_response_status_stat(live_service)
    # 11.Stream流量查询
    example_describe_live_metric_traffic_data(live_service)
    # 12.Stream带宽查询
    example_describe_live_metric_bandwidth_data(live_service)
    # 13.拉流域名查询流列表
    example_describe_play_stream_list(live_service)
    # 14.拉流转推带宽查询
    example_describe_pull_to_push_bandwidth_data(live_service)



# coding:utf-8
import json


class ComplexEncoder(json.JSONEncoder):
    def default(self, o):
        if isinstance(o, Statement):
            return {'Effect': o.effect,
                    'Action': o.action,
                    'Resource': o.resource}
        if isinstance(o, InnerToken):
            return {
                'LTAccessKeyId': o.lt_access_key_id,
                'AccessKeyId': o.access_key_id,
                'SignedSecretAccessKey': o.signed_secret_access_key,
                'ExpiredTime': o.expired_time,
                'PolicyString': o.policy_string,
                'Signature': o.signature
            }
        if isinstance(o, Policy):
            return {
                'Statement': [item for item in o.statements]
            }
        return json.JSONEncoder.default(self, o)


class Policy(object):
    def __init__(self, statements):
        self.statements = statements


class Statement(object):
    def __init__(self):
        self.effect = ''
        self.action = []
        self.resource = []
        self.condition = ''

    @staticmethod
    def new_allow_statement(actions, resources):
        s = Statement()
        s.effect = "Allow"
        s.action = actions
        s.resource = resources
        return s

    @staticmethod
    def new_deny_statement(actions, resources):
        s = Statement()
        s.effect = "Deny"
        s.action = actions
        s.resource = resources
        return s


class SecurityToken2(object):
    def __init__(self):
        self.access_key_id = ''
        self.secret_access_key = ''
        self.session_token = ''
        self.expired_time = ''
        self.current_time = ''

    def __str__(self):
        return json.dumps({
            'AccessKeyID': self.access_key_id,
            'SecretAccessKey': self.secret_access_key,
            'SessionToken': self.session_token,
            'ExpiredTime': self.expired_time,
            'CurrentTime': self.current_time
        })


class InnerToken(object):
    def __init__(self):
        self.lt_access_key_id = ''
        self.access_key_id = ''
        self.signed_secret_access_key = ''
        self.expired_time = 0
        self.policy_string = ''
        self.signature = ''

    def __str__(self):
        return json.dumps({
            'LTAccessKeyId': self.lt_access_key_id,
            'AccessKeyId': self.access_key_id,
            'SignedSecretAccessKey': self.signed_secret_access_key,
            'ExpiredTime': self.expired_time,
            'PolicyString': self.policy_string,
            'Signature': self.signature
        })



#  -*- coding: utf-8 -*-
from __future__ import print_function

from volcengine.nlp.NLPService import NLPService

if __name__ == '__main__':
    nlp_service = NLPService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    nlp_service.set_ak('ak')
    nlp_service.set_sk('sk')

    params = dict()

    form = {
        "title": "汽车",
        "text": "例如会让部件磨损大，使得寿命降低，而且还带来动力降低，油耗越来越高，抖动大等。以前一箱油能跑380公里的，如今却只能跑到350了，无疑也增加了开车成本。",
        "max_len": 5
    }

    resp = nlp_service.text_summarization(form)
    print(resp)



# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service


class VEditService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(VEditService, "_instance"):
            with VEditService._instance_lock:
                if not hasattr(VEditService, "_instance"):
                    VEditService._instance = object.__new__(cls)
        return VEditService._instance

    def __init__(self, region='cn-north-1'):
        self.service_info = VEditService.get_service_info(region)
        self.api_info = VEditService.get_api_info()
        super(VEditService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info_map = {
            'cn-north-1': ServiceInfo("vedit.volcengineapi.com", {'Accept': 'application/json'},
                                      Credentials('', '', 'edit', 'cn-north-1'), 5, 5, "https")
        }
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('Cant find the region, please check it carefully')

        return service_info

    @staticmethod
    def get_api_info():
        api_info = {"SubmitDirectEditTaskAsync": ApiInfo("POST", "/", {"Action": "SubmitDirectEditTaskAsync",
                                                                       "Version": "2018-01-01"}, {}, {}),
                    "GetDirectEditResult": ApiInfo("POST", "/", {"Action": "GetDirectEditResult",
                                                                 "Version": "2018-01-01"}, {}, {}),
                    "SubmitTemplateTaskAsync": ApiInfo("POST", "/", {"Action": "SubmitTemplateTaskAsync",
                                                                     "Version": "2018-01-01"}, {}, {})
                    }
        return api_info

    def submit_direct_edit_task_async(self, body):
        res = self.json('SubmitDirectEditTaskAsync', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def get_direct_edit_result(self, body):
        res = self.json('GetDirectEditResult', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def submit_template_task_async(self, body):
        res = self.json('SubmitTemplateTaskAsync', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json
